@@ -1,5 +1,6 @@
-"""This module contains the MythX request domain models"""
+"""This module contains the MythX request domain models."""
 
+from mythx_models.request.analysis_input import AnalysisInputRequest
 from mythx_models.request.analysis_list import AnalysisListRequest
 from mythx_models.request.analysis_status import AnalysisStatusRequest
 from mythx_models.request.analysis_submission import AnalysisSubmissionRequest
@@ -7,6 +8,9 @@ from mythx_models.request.auth_login import AuthLoginRequest
 from mythx_models.request.auth_logout import AuthLogoutRequest
 from mythx_models.request.auth_refresh import AuthRefreshRequest
 from mythx_models.request.detected_issues import DetectedIssuesRequest
+from mythx_models.request.group_creation import GroupCreationRequest
+from mythx_models.request.group_list import GroupListRequest
+from mythx_models.request.group_operation import GroupOperationRequest
+from mythx_models.request.group_status import GroupStatusRequest
 from mythx_models.request.oas import OASRequest
 from mythx_models.request.version import VersionRequest
-from mythx_models.request.analysis_input import AnalysisInputRequest
