@@ -1,6 +1,7 @@
-"""This module contains the MythX response domain models"""
+"""This module contains the MythX response domain models."""
 
 from mythx_models.response.analysis import Analysis, AnalysisStatus
+from mythx_models.response.analysis_input import AnalysisInputResponse
 from mythx_models.response.analysis_list import AnalysisListResponse
 from mythx_models.response.analysis_status import AnalysisStatusResponse
 from mythx_models.response.analysis_submission import AnalysisSubmissionResponse
@@ -8,14 +9,24 @@ from mythx_models.response.auth_login import AuthLoginResponse
 from mythx_models.response.auth_logout import AuthLogoutResponse
 from mythx_models.response.auth_refresh import AuthRefreshResponse
 from mythx_models.response.detected_issues import DetectedIssuesResponse, IssueReport
+from mythx_models.response.group import (
+    Group,
+    GroupState,
+    GroupStatistics,
+    VulnerabilityStatistics,
+)
+from mythx_models.response.group_creation import GroupCreationResponse
+from mythx_models.response.group_list import GroupListResponse
+from mythx_models.response.group_operation import GroupOperationResponse
+from mythx_models.response.group_status import GroupStatusResponse
 from mythx_models.response.issue import (
+    DecodedLocation,
     Issue,
     Severity,
     SourceFormat,
     SourceLocation,
+    SourceMap,
     SourceType,
 )
 from mythx_models.response.oas import OASResponse
 from mythx_models.response.version import VersionResponse
-from mythx_models.response.issue import SourceMap
-from mythx_models.response.analysis_input import AnalysisInputResponse
