@@ -1,6 +1,9 @@
 from mythx_models.request import VersionRequest
 
-from . import common as testdata
+from .common import get_test_case
+
+JSON_DATA, DICT_DATA = get_test_case("testdata/version-request.json")
+OBJ_DATA = VersionRequest.from_json(JSON_DATA)
 
 
 def assert_version_request(req):
@@ -11,19 +14,19 @@ def assert_version_request(req):
     assert req.endpoint == "v1/version"
 
 
-def test_auth_logout_request_from_valid_json():
+def test_version_request_from_valid_json():
     req = VersionRequest.from_json("{}")
     assert_version_request(req)
 
 
-def test_auth_logout_request_from_valid_dict():
+def test_version_request_from_valid_dict():
     req = VersionRequest.from_dict({})
     assert_version_request(req)
 
 
-def test_auth_logout_request_to_json():
-    assert testdata.VERSION_REQUEST_OBJECT.to_json() == "{}"
+def test_version_request_to_json():
+    assert OBJ_DATA.to_json() == "{}"
 
 
-def test_auth_logout_request_to_dict():
-    assert testdata.VERSION_REQUEST_OBJECT.to_dict() == {}
+def test_version_request_to_dict():
+    assert OBJ_DATA.to_dict() == {}
